init -100 python:
    import hashlib
    import io
    import math

    IMAGE_FILE_EXTENSIONS = ('.jpg', '.jpeg', '.png', '.webp')
    VIDEO_FILE_EXTENSIONS = (".webm", ".mp4", ".mkv", ".m4v", ".mpg", ".ogv", ".avi")

    ## TO BE SET BY RENPY BUILDER
    needs_video_rendering_refactor = False

    def _get_movie_animation_variable_name(animation_file):
        # Format folder path
        folder_path = animation_file
        file_extension_index = 0
        is_file_extension_stripped = False
        while not is_file_extension_stripped and file_extension_index < len(VIDEO_FILE_EXTENSIONS):
            if folder_path.endswith(VIDEO_FILE_EXTENSIONS[file_extension_index]):
                folder_path = folder_path[0:-len(VIDEO_FILE_EXTENSIONS[file_extension_index])]
                is_file_extension_stripped = True
            else:
                file_extension_index += 1

        folder_path = folder_path.lstrip("/") + "-animation"
        path_prefixes = renpy.loader.get_prefixes()
        path_prefixes_index = 0
        is_file_found = False

        while not is_file_found and path_prefixes_index < len(path_prefixes):
            try:
                # Get variable name
                first_frame_file = "{0}/00000.frame.webp".format(folder_path)
                file_path = path_prefixes[path_prefixes_index] + first_frame_file

                full_path = renpy.loader.transfn(file_path)
                if io.open(full_path, "rb").read():
                    md5_hash = hashlib.md5()
                    md5_hash.update(file_path.lower().encode())
                    return "animation_{0}".format(md5_hash.hexdigest())

            except:
                path_prefixes_index += 1

        return "#000000"

    if needs_video_rendering_refactor:
        old_audio_load = renpy.audio.audio.load

        def new_audio_load(fn):
            if fn.endswith(VIDEO_FILE_EXTENSIONS):
                renpy.store.web_movie_to_play = fn
                rv = open(os.path.join(renpy.config.commondir, '_dl_silence.ogg'), 'rb')
                return rv

            return old_audio_load(fn)

        renpy.audio.audio.load = new_audio_load

    if needs_video_rendering_refactor:
        def new_movie_predict_one(self):
            if not hasattr(self, "last_movie_animation"):
                return

            animation_variable_name = self.last_movie_animation[1]

            if animation_variable_name is not None:
                renpy.easy.predict(animation_variable_name)

        renpy.display.video.Movie.predict_one = new_movie_predict_one

    if needs_video_rendering_refactor:
        def new_movie_render(self, width, height, st, at):
            if hasattr(self, "_original_play"):
                self._play = self._original_play

            if self._play is not None:
                if not hasattr(self, "last_movie_animation"):
                    self.last_movie_animation = (self._play, _get_movie_animation_variable_name(animation_file=self._play))

                animation_variable_name = self.last_movie_animation[1]

            elif hasattr(renpy.store, "web_movie_to_play") and renpy.store.web_movie_to_play is not None:
                animation_variable_name = _get_movie_animation_variable_name(animation_file=renpy.store.web_movie_to_play)
                self.last_movie_animation = (renpy.store.web_movie_to_play, animation_variable_name)
                self._play = self.last_movie_animation[1]

            else:
                animation_variable_name = None

            if animation_variable_name is not None:
                movie_displayable = renpy.easy.displayable_or_none(animation_variable_name)
                surf = renpy.display.render.render(movie_displayable, width, height, st, at)

                if self.size is not None:
                    w, h = self.size
                else:
                    w, h = surf.get_size()

                rv = renpy.display.render.Render(w, h)
                rv.blit(surf, (0, 0))

            else:
                rv = renpy.display.render.Render(width, height)

            renpy.display.render.redraw(self, 0.1)

            return rv

        renpy.display.video.Movie.render = new_movie_render

    if needs_video_rendering_refactor:
        class SideMaskDisplayable(renpy.Displayable):
            def __init__(self, original_displayable, **kwargs):
                super(SideMaskDisplayable, self).__init__(**kwargs)
                self.original_displayable = original_displayable

            def predict_one(self):
                self.original_displayable.predict_one()

            def render(self, width, height, st, at):
                surf = renpy.display.render.render(self.original_displayable, width, height, st, at)

                if surf is not None:
                    w, h = surf.get_size()
                    w //= 2
                    mask_surf = surf.subsurface((w, 0, w, h))
                    surf = surf.subsurface((0, 0, w, h))

                else:
                    mask_surf = None

                if mask_surf is not None:
                    rv = renpy.display.render.Render(*surf.get_size())
                    rv.blit(surf, (0, 0))
                    rv.blit(mask_surf, (0, 0))
                    rv.mesh = True
                    rv.add_shader("renpy.alpha_mask")

                else:
                    surf = None
                    rv = renpy.display.render.Render(width, height)

                return rv

        def Movie(*movie_args, **movie_kwargs):
            if len(movie_args) > 0 or "play" in movie_kwargs:
                animation_file = movie_args[0] if len(movie_args) > 0 else movie_kwargs["play"]

                # TODO: add support for this
                if isinstance(animation_file, list):
                    animation_file = animation_file[0]

                # TODO: add support for this
                if isinstance(animation_file, tuple):
                    animation_file = animation_file[0]

                if animation_file.endswith(IMAGE_FILE_EXTENSIONS):
                    return renpy.easy.displayable_or_none(animation_file)

                animation_variable_name = _get_movie_animation_variable_name(animation_file)
                animation_displayable = renpy.easy.displayable_or_none(animation_variable_name)

                if "size" in movie_kwargs:
                    animation_displayable = Transform(animation_displayable, size=movie_kwargs["size"])

                if "side_mask" in movie_kwargs and movie_kwargs["side_mask"] is True:
                    animation_displayable = SideMaskDisplayable(animation_displayable)

                return animation_displayable

            return renpy.display.video.Movie(**movie_kwargs)

    if needs_video_rendering_refactor:
        def new_movie_cutscene(filename, delay=None, loops=0, stop_music=True):
            animation_variable_name = _get_movie_animation_variable_name(animation_file=filename)

            renpy.exports.scene()
            renpy.exports.show("new_movie_cutscene_movie", what=renpy.display.imagelike.Frame(animation_variable_name))
            renpy.exports.pause()

        renpy.exports.movie_cutscene = new_movie_cutscene

    old_image_load = renpy.display.im.Image.load

    if needs_video_rendering_refactor:
        def new_image_load(self, unscaled=False):
            if self.filename.endswith(".frame.webp"):
                renpy.display.im.cache.add_load_log(self.filename)
                exception = None
                try:
                    filelike = renpy.loader.load(self.filename)
                    filename = self.filename
                except renpy.webloader.DownloadNeeded as downloadNeededException:
                    exception = downloadNeededException
                    renpy.webloader.enqueue(downloadNeededException.relpath, 'image', self.filename)
                    is_last_loaded_frame_found = False
                    frame_index = int(self.filename[-len(".frame.webp") - 5:-len(".frame.webp")])
                    while not is_last_loaded_frame_found and frame_index > 0:
                        try:
                            frame_index -= 1
                            previous_frame_filename = self.filename[:-len(".frame.webp") - 5] + "{:05d}.frame.webp".format(frame_index)
                            filelike = renpy.loader.load(previous_frame_filename)
                            filename = previous_frame_filename
                            is_last_loaded_frame_found = True
                        except renpy.webloader.DownloadNeeded:
                            pass
                    if not is_last_loaded_frame_found:
                        raise

                if unscaled:
                    surf = renpy.display.pgrender.load_image_unscaled(filelike, filename)
                else:
                    surf = renpy.display.pgrender.load_image(filelike, filename)

                if exception is not None:
                    # avoid size-related exceptions (e.g. Crop on a smaller placeholder)
                    surf = renpy.display.pgrender.transform_scale(surf, exception.size)

                return surf

            return old_image_load(self, unscaled)

        renpy.display.im.Image.load = new_image_load

    if needs_video_rendering_refactor:
        old_music_play = renpy.music.play

        def new_music_play(filenames, *play_args, **play_kwargs):
            if "channel" in play_kwargs and play_kwargs["channel"] == "movie" and filenames is not None:
                if isinstance(filenames, basestring):
                    filename = filenames
                else:
                    filename = filenames[0]

                animation_variable_name = _get_movie_animation_variable_name(animation_file=filename)

                renpy.exports.scene()
                renpy.exports.show("new_music_play_movie", what=renpy.display.imagelike.Frame(animation_variable_name), zorder=69)

                return

            old_music_play(filenames, *play_args, **play_kwargs)

        renpy.music.play = new_music_play

    config.hw_video = False

    old_config = config

    class _ConfigWrapper(_Config):
        def __getattr__(self, name):
            try:
                return getattr(old_config, name)

            except Exception as exception:
                if "is not a known configuration variable" not in str(exception):
                    raise exception

                return None

        def __setattr__(self, name, value):
            try:
                setattr(old_config, name, value)

            except Exception as exception:
                if "is not a known configuration variable" not in str(exception):
                    raise exception

    config = _ConfigWrapper()
    config.special_namespaces["store.config"].nso = config

    def new_variant(name):
        if name == "pc":
            return True

        return False

    renpy.variant = new_variant

    old_renpy_text_font_load_face = renpy.text.font.load_face

    def new_renpy_text_font_load_face(fn, *args, **kwargs):
        try:
            return old_renpy_text_font_load_face(fn, *args, **kwargs)
        except Exception as exception:
            if "Could not find font" in str(exception):
                return old_renpy_text_font_load_face("DejaVuSans.ttf")

            raise exception

    renpy.text.font.load_face = new_renpy_text_font_load_face

    class _keymap_list(_list):
        def remove(self, a):
            try:
                _list.remove(self, a)
            except ValueError:
                pass

    config.keymap = { k : _keymap_list(v) for k, v in config.keymap.items() }

    old_hide_screen = renpy.hide_screen

    def new_hide_screen(*args, **kwargs):
        try:
            return old_hide_screen(*args, **kwargs)
        except IndexError:
            pass

    renpy.hide_screen = new_hide_screen

    if "images/" not in config.search_prefixes:
        config.search_prefixes.append("images/")

init -50 python:
    old_preference = Preference

    def new_preference(name, value=None, range=None):
        try:
            return old_preference(name, value=value, range=range)

        except Exception as exception:
            if "is unknown." not in str(exception):
                raise exception

            return NullAction()

    Preference = new_preference

init 50 python:
    try:
        import emscripten

        if emscripten.run_script_string("window.location.hostname") == "127.0.0.1":
            config.console = True
            preferences.skip_unseen = True
    except:
        pass

    config.window_icon = None
