﻿################################################################################
## Initialization
################################################################################

init offset = -1



label escape_menu_trans:
    pause 1.0
################################################################################
## Styles
################################################################################

style default:
    properties gui.text_properties()
    language gui.language

style input:
    properties gui.text_properties("input", accent=True)
    adjust_spacing False

style hyperlink_text:
    properties gui.text_properties("hyperlink", accent=True)
    hover_underline True

style gui_text:
    properties gui.text_properties("interface")


style button:
    properties gui.button_properties("button")
    #hover_sound "audio/button_hover.wav"

style button_text is gui_text:
    properties gui.text_properties("button")
    yalign 0.5


style label_text is gui_text:
    properties gui.text_properties("label", accent=True)

style prompt_text is gui_text:
    properties gui.text_properties("prompt")


style bar:
    ysize gui.bar_size
    left_bar Frame("gui/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    xsize gui.bar_size
    top_bar Frame("gui/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    ysize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    xsize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    ysize gui.slider_size
    base_bar Frame("gui/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/slider/horizontal_[prefix_]thumb.png"
    hover_sound "audio/button_hover.wav"

style vslider:
    xsize gui.slider_size
    base_bar Frame("gui/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/slider/vertical_[prefix_]thumb.png"

style frame:
    padding gui.frame_borders.padding
    background Frame("gui/frame.png", gui.frame_borders, tile=gui.frame_tile)

## multiple textbox script
style multiple2_say_window:
    xsize 500
    background None

style block1_multiple2_say_window:
    xalign 0.0

style block2_multiple2_say_window:
    xalign 0.5


################################################################################
## In-game screens
################################################################################


## Say screen ##################################################################
##
## The say screen is used to display dialogue to the player. It takes two
## parameters, who and what, which are the name of the speaking character and
## the text to be displayed, respectively. (The who parameter can be None if no
## name is given.)
##
## This screen must create a text displayable with id "what", as Ren'Py uses
## this to manage text display. It can also create displayables with id "who"
## and id "window" to apply style properties.
##
## https://www.renpy.org/doc/html/screen_special.html#say

screen say(who, what):
    style_prefix "say"

    window:
        id "window"

        if who is not None:

            window:
                id "namebox"
                style "namebox"
                text who id "who"

        text what id "what"


    ## If there's a side image, display it above the text. Do not display on the
    ## phone variant - there's no room.
    if not renpy.variant("small"):
        add SideImage() xalign 0.0 yalign 1.0


## Make the namebox available for styling through the Character object.
init python:
    config.character_id_prefixes.append('namebox')

style window is default
style say_label is default
style say_dialogue is default
style say_thought is say_dialogue

style namebox is default
style namebox_label is say_label


style window:
    xalign 0.5
    xfill True
    yalign gui.textbox_yalign
    ysize gui.textbox_height

    background Image("gui/textbox.png", xalign=0.5, yalign=1.0)

style namebox:
    xpos gui.name_xpos
    xanchor gui.name_xalign
    xsize gui.namebox_width
    ypos gui.name_ypos
    ysize gui.namebox_height

    background Frame("gui/namebox.png", gui.namebox_borders, tile=gui.namebox_tile, xalign=gui.name_xalign)
    padding gui.namebox_borders.padding

style say_label:
    properties gui.text_properties("name", accent=True)
    xalign gui.name_xalign
    yalign 0.5

style say_dialogue:
    properties gui.text_properties("dialogue")

    xpos gui.dialogue_xpos
    xsize gui.dialogue_width
    ypos gui.dialogue_ypos


## Input screen ################################################################
##
## This screen is used to display renpy.input. The prompt parameter is used to
## pass a text prompt in.
##
## This screen must create an input displayable with id "input" to accept the
## various input parameters.
##
## https://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):
    style_prefix "input"

    window:

        vbox:
            xalign gui.dialogue_text_xalign
            xpos gui.dialogue_xpos
            xsize gui.dialogue_width
            ypos gui.dialogue_ypos

            text prompt style "input_prompt"
            input id "input"

style input_prompt is default

style input_prompt:
    xalign gui.dialogue_text_xalign
    properties gui.text_properties("input_prompt")

style input:
    xalign gui.dialogue_text_xalign
    xmaximum gui.dialogue_width


## Choice screen ###############################################################
##
## This screen is used to display the in-game choices presented by the menu
## statement. The one parameter, items, is a list of objects, each with caption
## and action fields.
##
## https://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):
    style_prefix "choice"

    vbox:
        for i in items:
            textbutton i.caption action i.action


## When this is true, menu captions will be spoken by the narrator. When false,
## menu captions will be displayed as empty buttons.
define config.narrator_menu = True


style choice_vbox is vbox
style choice_button is button
style choice_button_text is button_text

style choice_vbox:
    #xalign 0.5
    #ypos 405
    #yanchor 0.5

    xalign 0.0
    yalign 0.5

    spacing gui.choice_spacing

style choice_button is default:
    properties gui.button_properties("choice_button")

style choice_button_text is default:
    properties gui.button_text_properties("choice_button")


## Quick Menu screen ###########################################################
##
## The quick menu is displayed in-game to provide easy access to the out-of-game
## menus.
default show_quick_menu = True
screen quick_menu():

    ## Ensure this appears on top of other screens.
    zorder 100

    if show_quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            textbutton _("Back") action Rollback()
            #textbutton _("History") action ShowMenu('history')
            textbutton _("Skip") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            #textbutton _("Save") action ShowMenu('save')
            textbutton _("Quick Save") action QuickSave()
            #textbutton _("Q.Load") action QuickLoad()
            textbutton _("Hide") action HideInterface()
            #textbutton _("Prefs") action ShowMenu('preferences')


## This code ensures that the quick_menu screen is displayed in-game, whenever
## the player has not explicitly hidden the interface.
init python:
    config.overlay_screens.append("quick_menu")

default quick_menu = True

style quick_button is default
style quick_button_text is button_text

style quick_button:
    properties gui.button_properties("quick_button")

style quick_button_text:
    properties gui.button_text_properties("quick_button")



################################################################################
## Main and Game Menu Screens
################################################################################

## Navigation screen ###########################################################
##
## This screen is included in the main and game menus, and provides navigation
## to other menus, and to start the game.

#screen navigation():



style navigation_button is gui_button
style navigation_button_text is gui_button_text

style navigation_button:
    size_group "navigation"
    properties gui.button_properties("navigation_button")

style navigation_button_text:
    properties gui.button_text_properties("navigation_button")


## Main Menu screen ############################################################
##
## Used to display the main menu when Ren'Py starts.
##
## https://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    ## This ensures that any other menu screen is replaced.
    tag menu

    style_prefix "main_menu"

    add gui.main_menu_background

    ## This empty frame darkens the main menu.
    frame:
        pass

    ## The use statement includes another screen inside this one. The actual
    ## contents of the main menu are in the navigation screen.

    #use navigation

    fixed:
        style_prefix "navigation"

        #xpos gui.navigation_xpos
        #yalign 0.5

        spacing gui.navigation_spacing

        if main_menu:

            #textbutton _("Start") action Start()
            imagebutton auto "gui/mm_new_story_%s.png" xpos 463 ypos 910 action ShowMenu("start_animation") hovered [Play("sound", "audio/button_hover.wav")]

        else:

            textbutton _("History") action ShowMenu("history")

            textbutton _("Save") action ShowMenu("save")

        #textbutton _("Load") action ShowMenu("load")
        imagebutton auto "gui/mm_load_story_%s.png" xpos 674 ypos 910 action ShowMenu("load") hovered [Play("sound", "audio/button_hover.wav")]

        #textbutton _("Preferences") action ShowMenu("preferences")
        imagebutton auto "gui/mm_game_settings_%s.png" xpos 1135 ypos 910 action ShowMenu("preferences") hovered [Play("sound", "audio/button_hover.wav")]

        imagebutton auto "gui/mm_extra_content_%s.png" xalign 0.5 ypos 910 action ShowMenu("extras") hovered [Play("sound", "audio/button_hover.wav")]

        textbutton _("{color=#7A7054}{size=35}{alpha=0.6}Credits") xalign 0.0 ypos 0.955 action ShowMenu("credits")

        if persistent.CardNotifi == True or persistent.SceneNotifi == True:
            add "award_room_blink" xalign 0.5 ypos 910

        if _in_replay:

            textbutton _("End Replay") action EndReplay(confirm=True)

        elif not main_menu:

            textbutton _("Main Menu") action MainMenu()

        #textbutton _("About") action ShowMenu("about")

        #if renpy.variant("pc") or (renpy.variant("web") and not renpy.variant("mobile")):

            ## Help isn't necessary or relevant to mobile devices.
            #textbutton _("Help") action ShowMenu("help")

        if renpy.variant("pc"):

            ## The quit button is banned on iOS and unnecessary on Android and
            ## Web.
            #textbutton _("Quit") action Quit(confirm=not main_menu)
            imagebutton auto "gui/mm_quit_game_%s.png" xpos 1380 ypos 910 action Quit(confirm=not main_menu) hovered [Play("sound", "audio/button_hover.wav")]

        #add "gui/mm_community.png" xalign 0.5 yalign 0.95

        #on patreon version x 0.5, 0.55, 0.45
        #on steam version x - 0.525 0.475
        #button:
        #    xalign 0.5
        #    yalign 1.006
        #    add "patreon"
        #    action OpenURL("https://www.patreon.com/dokiden")

        add "gui/mm_support.png" xalign 0.42 yalign 0.95
        add "gui/mm_community.png" xalign 0.6 yalign 0.95

        #on patreon version x 0.5, 0.55, 0.45
        #on steam version x - 0.525 0.475
        button:
            xalign 0.35
            yalign 1.006
            add "patreon"
            action OpenURL("https://www.patreon.com/dokiden")

        button:
            xalign 0.40
            yalign 1.006
            add "itch"
            action OpenURL("https://dokiden.itch.io/dreamland")

        button:
            xalign 0.45
            yalign 1.006
            add "oppaiman"
            action OpenURL("http://oppai.me/Dreamland__Chapter_2")

        button:
            xalign 0.50
            yalign 1.006
            add "steam"
            action OpenURL("https://store.steampowered.com/app/2176560/Dreamland/")

        button:
            xalign 0.6225
            yalign 1.006
            add "twitter"
            action OpenURL("https://twitter.com/DokidenGames")

        button:
            xalign 0.5725
            yalign 1.006
            add "discord"
            action OpenURL("https://discord.gg/Q7jG6UuUey")



        text "{color=#7A7054}{size=17}{alpha=0.6}[config.version]" xalign 1.0 yalign 1.0

    if gui.show_name:

        vbox:
            text "[config.name!t]":
                style "main_menu_title"

            text "[config.version]":
                style "main_menu_version"


style main_menu_frame is empty
style main_menu_vbox is vbox
style main_menu_text is gui_text
style main_menu_title is main_menu_text
style main_menu_version is main_menu_text

style main_menu_frame:
    #xsize 420
    #yfill True

    background "main_menu"

style main_menu_vbox:
    xalign 1.0
    xoffset -30
    xmaximum 1200
    yalign 1.0
    yoffset -30

style main_menu_text:
    properties gui.text_properties("main_menu", accent=True)

style main_menu_title:
    properties gui.text_properties("title")

style main_menu_version:
    properties gui.text_properties("version")

## Escape Menu screen ##########################################################

screen escape_menu():
    add "gui/mm_title.png"

    imagebutton auto "gui/mm_main_menu_%s.png" xpos 460 ypos 910 action [MainMenu(), Hide("escape_menu")] hovered [Play("sound", "audio/button_hover.wav")]
    if persistent.CardNotifi == True or persistent.SceneNotifi == True:
        add "main_menu_blink" xpos 460 ypos 910
    imagebutton auto "gui/mm_load_story_%s.png" xpos 670 ypos 910 action [ShowMenu("load"), Hide("escape_menu")] hovered [Play("sound", "audio/button_hover.wav")]
    imagebutton auto "gui/mm_save_progress_%s.png" xpos 882 ypos 910 action [ShowMenu("save"), Hide("escape_menu")] hovered [Play("sound", "audio/button_hover.wav")]
    imagebutton auto "gui/mm_game_settings_%s.png" xpos 1140 ypos 910 action [ShowMenu("preferences"), Hide("escape_menu")] hovered [Play("sound", "audio/button_hover.wav")]
    imagebutton auto "gui/mm_quit_game_%s.png" xpos 1380 ypos 910 action [Quit(confirm=not main_menu), Hide("escape_menu")] hovered [Play("sound", "audio/button_hover.wav")]
    key "K_ESCAPE" action [Show("escape_menu_exit_animation"), Hide("escape_menu"),Jump("escape_menu_trans"), Return()]
    key "mouseup_3" action [Show("escape_menu_exit_animation"), Hide("escape_menu"),Jump("escape_menu_trans"), Return()]
    #imagebutton auto "gui/mm_main_menu_%s.png" xpos 157 ypos 300 action MainMenu() hovered [Play("sound", "audio/button_hover.wav")]
    #imagebutton auto "gui/mm_save_progress_%s.png" xpos 122 ypos 400 action ShowMenu("save") hovered [Play("sound", "audio/button_hover.wav")]
    #imagebutton auto "gui/mm_load_story_%s.png" xpos 153 ypos 500 action ShowMenu("load") hovered [Play("sound", "audio/button_hover.wav")]
    #imagebutton auto "gui/mm_game_settings_%s.png" xpos 132 ypos 600 action ShowMenu("preferences") hovered [Play("sound", "audio/button_hover.wav")]
    #imagebutton auto "gui/mm_quit_game_%s.png" xpos 156 ypos 700 action Quit(confirm=not main_menu) hovered [Play("sound", "audio/button_hover.wav")]
    #imagebutton auto "gui/mm_return_%s.png" xpos 140 ypos 926 action Return() hovered [Play("sound", "audio/button_hover.wav")]

screen escape_menu_enter_animation_delay():
    timer 0.15 action Show("escape_menu_enter_animation")
screen escape_menu_enter_animation():
    add "escape_menu_in"
    timer 0.95 action [Show("escape_menu"),Hide("escape_menu_enter_animation")]
screen escape_menu_exit_animation():
    add "escape_menu_out"

## Start story animation with black screen
screen start_animation():
    add "closings_h_close_long"
    timer 5.0 action Start()

## Game Menu screen ############################################################
##
## This lays out the basic common structure of a game menu screen. It's called
## with the screen title, and displays the background, title, and navigation.
##
## The scroll parameter can be None, or one of "viewport" or "vpgrid". When
## this screen is intended to be used with one or more children, which are
## transcluded (placed) inside it.


screen game_menu(title, scroll=None, yinitial=0.0):

    style_prefix "game_menu"

    if main_menu:
        add gui.main_menu_background
    else:
        add gui.game_menu_background

    frame:
        style "game_menu_outer_frame"

        hbox:

            ## Reserve space for the navigation section.
            frame:
                style "game_menu_navigation_frame"

            frame:
                style "game_menu_content_frame"

                if scroll == "viewport":

                    viewport:
                        yinitial yinitial
                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        vbox:
                            transclude

                elif scroll == "vpgrid":

                    vpgrid:
                        cols 1
                        yinitial yinitial

                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        transclude

                else:

                    transclude

    #use navigation

    fixed:
        style_prefix "navigation"
        spacing gui.navigation_spacing
        if _in_replay:

            textbutton _("End Replay") action EndReplay(confirm=True)

    if main_menu:
        imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action Return() hovered [Play("sound", "audio/button_hover.wav")]
    elif _in_replay:
        timer 0.0001 action EndReplay(confirm=False) ##
    else:
        imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("load"), Hide("save"), Hide("preferences"),ShowMenu("escape_menu")] hovered [Play("sound", "audio/button_hover.wav")]
    #textbutton _("Return"):
        #style "return_button"

        #action Return()

    label title

    if main_menu:
        key "game_menu" action ShowMenu("main_menu")


style game_menu_outer_frame is empty
style game_menu_navigation_frame is empty
style game_menu_content_frame is empty
style game_menu_viewport is gui_viewport
style game_menu_side is gui_side
style game_menu_scrollbar is gui_vscrollbar

style game_menu_label is gui_label
style game_menu_label_text is gui_label_text

style return_button is navigation_button
style return_button_text is navigation_button_text

style game_menu_outer_frame:
    bottom_padding 45
    top_padding 180

    background "gui/overlay/game_menu.png"

style game_menu_navigation_frame:
    xsize 420
    yfill True

style game_menu_content_frame:
    left_margin 60
    right_margin 30
    top_margin 15

style game_menu_viewport:
    xsize 1920
    #xsize 1380

style game_menu_vscrollbar:
    unscrollable gui.unscrollable

style game_menu_side:
    spacing 15

style game_menu_label:
    xpos 75
    ysize 180

style game_menu_label_text:
    size gui.title_text_size
    color gui.accent_color
    yalign 0.5

style return_button:
    xpos gui.navigation_xpos
    yalign 1.0
    yoffset -45



## Gallery -----------------------------------------------------------------------
screen extras():

    tag menu

    add "black_bg.jpg"

    button:
        yalign 0.57
        xalign 1.05
        add "cards_button"
        if persistent.CardScreen == 2:
            action [ShowMenu("smm_gallery"), SetField(persistent, "CardNotifi", False)]
        elif persistent.CardScreen == 3:
            action [ShowMenu("dan_gallery"), SetField(persistent, "CardNotifi", False)]
        elif persistent.CardScreen == 4:
            action [ShowMenu("ali_gallery"), SetField(persistent, "CardNotifi", False)]
        elif persistent.CardScreen == 5:
            action [ShowMenu("mei_gallery"), SetField(persistent, "CardNotifi", False)]
        elif persistent.CardScreen == 6:
            action [ShowMenu("kat_gallery"), SetField(persistent, "CardNotifi", False)]
        else:
            action [ShowMenu("lea_gallery"), SetField(persistent, "CardNotifi", False)]

    button:
        yalign 0.57
        xalign -0.15
        add "scenes_button"
        action [ShowMenu("scenes"), SetField(persistent, "SceneNotifi", False)]

    add "gui/mm_collectables_split.png"
    add "gui/mm_bottom_bar.png"
    add "gui/mm_top_bar.png"
    add "gui/title_cards.png" yalign 0.21 xalign 0.8 zoom 0.5
    add "gui/title_scenes.png" yalign 0.21 xalign 0.2 zoom 0.5
    add "gui/title_collectables.png" xalign 0.5 ypos 50

    if persistent.CardNotifi == True:
        add "cards_blink" yalign 0.21 xalign 0.8 zoom 0.5
    if persistent.SceneNotifi == True:
        add "scenes_blink" yalign 0.21 xalign 0.2 zoom 0.5

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action Return() hovered [Play("sound", "audio/button_hover.wav")]

    #timer 0.001 action renpy.music.play("audio/music/Roadtrip.mp3","music")

screen scenes():

    tag menu

    add "black_bg.jpg"

    frame background None:
        xpos 40
        ypos -10
        xmaximum 1850
        ymaximum 1079
        xfill True
        viewport:
            scrollbars "vertical"
            draggable True
            mousewheel True
            vbox:
                ysize 0.25
                yalign 0.0
                xsize 0.9
                xalign 0.5
                fixed:
                    area (39, 0, 1750, 1500)
                    hbox:
                        grid 4 6:
                            xfill True
                            yfill True
                            add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5

                            if persistent.S_A_k == True:
                                imagebutton auto "C1/scene/A_k_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_k",locked = False)
                            else:
                                add "C1/scene/locked1.jpg" xalign 0.5 yalign 0.5

                            if persistent.S_A_l == True:
                                imagebutton auto "C1/scene/A_l_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_l", locked = False)
                            else:
                                add "C1/scene/locked1.jpg" xalign 0.5 yalign 0.5

                            # Chapter 2 -------
                            if persistent.patch_enabled == True and persistent.S_A_j == True:
                                imagebutton auto "C2/scene/A_j_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_j",locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5

                            if persistent.patch_enabled == True and persistent.S_A_x == True:
                                imagebutton auto "C2/scene/A_x_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_x", locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5


                            if persistent.patch_enabled == True and persistent.S_A_d == True:
                                imagebutton auto "C2/scene/A_d_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_d", locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5

                            if persistent.patch_enabled == True and persistent.S_A_n == True:
                                imagebutton auto "C2/scene/A_n_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_n", locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5

                            if persistent.patch_enabled == True and persistent.S_A_s == True:
                                imagebutton auto "C2/scene/A_s_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_s", locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5

                            if persistent.patch_enabled == True and persistent.S_A_oA == True:
                                imagebutton auto "C2/scene/A_oA_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_oA", locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5


                            if persistent.patch_enabled == True and persistent.S_A_oB == True:
                                imagebutton auto "C2/scene/A_oB_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_oB", locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5

                            if persistent.patch_enabled == True and persistent.S_A_oC == True:
                                imagebutton auto "C2/scene/A_oC_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_oC", locked = False)
                            else:
                                add "C1/scene/locked2.jpg" xalign 0.5 yalign 0.5

                            # Chapter 3--------
                            if persistent.patch2_enabled == True and persistent.S_A_xd == True:
                                imagebutton auto "C3/scene/A_xd_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_xd", locked = False)
                            else:
                                add "C1/scene/locked3.jpg" xalign 0.5 yalign 0.5

                            if persistent.patch2_enabled == True and persistent.S_A_xl == True:
                                imagebutton auto "C3/scene/A_xl_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_xl", locked = False)
                            else:
                                add "C1/scene/locked3.jpg" xalign 0.5 yalign 0.5



                            if persistent.patch2_enabled == True and persistent.S_A_xld == True:
                                imagebutton auto "C3/scene/A_xld_%s.jpg" xalign 0.5 yalign 0.5 action Replay("A_xld", locked = False)
                            else:
                                add "C1/scene/locked3.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/none.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/none.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/none.jpg" xalign 0.5 yalign 0.5

                            add "C1/scene/none.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/none.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/none.jpg" xalign 0.5 yalign 0.5
                            add "C1/scene/none.jpg" xalign 0.5 yalign 0.5

                            #add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5
                            #add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5
                            #add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5
                            #add "C1/scene/gap.jpg" xalign 0.5 yalign 0.5

    fixed:
        add "gui/mm_scenes_blur_line.png" xalign 0.5 ypos -600
        add "gui/mm_scenes_blur_line.png" xalign 0.5 ypos 230
        add "gui/closings.jpg" xalign 0.5 ypos -400
        add "gui/closings.jpg" xalign 0.5 ypos 980

        add "gui/title_scenes.png" xalign 0.5 ypos 50
    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("scenes"), Hide("chapter1_gallery"),  Hide("chapter2_gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]

    #imagebutton auto "gui/mm_return_%s.png" xalign 0.5 yalign 0.5 action Replay("A_l")

screen gallery():
    tag menu
    add "black_bg.jpg"
    fixed:
        add "gui/title_cards.png" xalign 0.5 ypos 50

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]

screen lea_gallery():

    tag menu
    add "black_bg.jpg"
    fixed:
        vbox:
            ysize 0.58
            yalign 0.51
            xsize 0.2
            xalign 0.91
            hbox:
                grid 1 6:
                    xfill True
                    yfill True

                    add "gui/mm_lea_hover.jpg" xalign 0.5 yalign 0.5 #hovered [Play("sound", "audio/button_hover.wav")]

                    button:
                        xalign 0.5
                        yalign 0.5
                        add "smm_gallery"
                        action [Hide("lea_gallery"), ShowMenu("smm_gallery"), SetField(persistent, "CardScreen", 2)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "dan_gallery"
                        action [Hide("lea_gallery"), ShowMenu("dan_gallery"), SetField(persistent, "CardScreen", 3)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "ali_gallery"
                        action [Hide("lea_gallery"), ShowMenu("ali_gallery"), SetField(persistent, "CardScreen", 4)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "mei_gallery"
                        action [Hide("lea_gallery"), ShowMenu("mei_gallery"), SetField(persistent, "CardScreen", 5)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "kat_gallery"
                        action [Hide("lea_gallery"), ShowMenu("kat_gallery"), SetField(persistent, "CardScreen", 6)] hovered [Play("sound", "audio/button_hover.wav")]
    vbox:
        ysize 0.3
        yalign 0.3
        xsize 0.6
        xalign 0.2
        hbox:
            grid 5 1:
                xfill True
                yfill True

                if persistent.G_I_s_4 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_l_1_card" zoom 0.37
                        action Replay("G_l_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.G_I_b_7 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_ls_1_card" zoom 0.37
                        action Replay("G_ls_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_II_c_2 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_l_2_card" zoom 0.37
                        action Replay("G_l_2", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_II_z_4 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_l_3_card" zoom 0.37
                        action Replay("G_l_3", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_III_s_42 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_l_4_card" zoom 0.37
                        action Replay("G_l_4", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5
    vbox:
        ysize 0.3
        yalign 0.72
        xsize 0.48
        xalign 0.27
        hbox:
            #box_wrap True
            grid 4 1:

                xfill True
                yfill True

                if persistent.patch_enabled == True and persistent.G_III_d_3 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_la_1_card" zoom 0.37
                        action Replay("G_la_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
    fixed:
        add "gui/title_cards.png" xalign 0.5 ypos 50

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]

screen smm_gallery():
    tag menu
    add "black_bg.jpg"
    fixed:
        vbox:
            ysize 0.58
            yalign 0.51
            xsize 0.2
            xalign 0.91
            hbox:
                grid 1 6:
                    xfill True
                    yfill True

                    button:
                        xalign 0.5
                        yalign 0.5
                        add "lea_gallery"
                        action [Hide("smm_gallery"), ShowMenu("lea_gallery"), SetField(persistent, "CardScreen", 1)] hovered [Play("sound", "audio/button_hover.wav")]
                    add "gui/mm_smm_hover.jpg" xalign 0.5 yalign 0.5 #hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "dan_gallery"
                        action [Hide("smm_gallery"), ShowMenu("dan_gallery"), SetField(persistent, "CardScreen", 3)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "ali_gallery"
                        action [Hide("smm_gallery"), ShowMenu("ali_gallery"), SetField(persistent, "CardScreen", 4)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "mei_gallery"
                        action [Hide("smm_gallery"), ShowMenu("mei_gallery"), SetField(persistent, "CardScreen", 5)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "kat_gallery"
                        action [Hide("smm_gallery"), ShowMenu("kat_gallery"), SetField(persistent, "CardScreen", 6)] hovered [Play("sound", "audio/button_hover.wav")]
    vbox:
        ysize 0.3
        yalign 0.3
        xsize 0.6
        xalign 0.2
        hbox:
            grid 5 1:
                xfill True
                yfill True

                if persistent.G_O_b_1 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_s_2_card" zoom 0.37
                        action Replay("G_s_2", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.G_I_b_7 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_ls_1_card" zoom 0.37
                        action Replay("G_ls_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.G_A_l_1 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_s_1_card" zoom 0.37
                        action Replay("G_s_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_II_n_1 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_s_3_card" zoom 0.37
                        action Replay("G_s_3", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_III_n_4 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_s_4_card" zoom 0.37
                        action Replay("G_s_4", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

    vbox:
        ysize 0.3
        yalign 0.72
        xsize 0.48
        xalign 0.27
        hbox:
            #box_wrap True
            grid 4 1:

                xfill True
                yfill True

                if persistent.patch_enabled == True and persistent.G_III_o_30 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_sm_1_card" zoom 0.37
                        action Replay("G_sm_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch2_enabled == True and persistent.G_A_xd_4 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_s_5_card" zoom 0.37
                        action Replay("G_s_5", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5





    fixed:
        add "gui/title_cards.png" xalign 0.5 ypos 50

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]

screen dan_gallery():

    tag menu
    add "black_bg.jpg"
    fixed:
        vbox:
            ysize 0.58
            yalign 0.51
            xsize 0.2
            xalign 0.91
            hbox:
                grid 1 6:
                    xfill True
                    yfill True

                    button:
                        xalign 0.5
                        yalign 0.5
                        add "lea_gallery"
                        action [Hide("dan_gallery"), ShowMenu("lea_gallery"), SetField(persistent, "CardScreen", 1)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "smm_gallery"
                        action [Hide("dan_gallery"), ShowMenu("smm_gallery"), SetField(persistent, "CardScreen", 2)] hovered [Play("sound", "audio/button_hover.wav")]
                    add "gui/mm_dan_hover.jpg" xalign 0.5 yalign 0.5 #hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "ali_gallery"
                        action [Hide("dan_gallery"), ShowMenu("ali_gallery"), SetField(persistent, "CardScreen", 4)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "mei_gallery"
                        action [Hide("dan_gallery"), ShowMenu("mei_gallery"), SetField(persistent, "CardScreen", 5)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "kat_gallery"
                        action [Hide("dan_gallery"), ShowMenu("kat_gallery"), SetField(persistent, "CardScreen", 6)] hovered [Play("sound", "audio/button_hover.wav")]
    vbox:
        ysize 0.3
        yalign 0.3
        xsize 0.6
        xalign 0.2
        hbox:
            grid 5 1:
                xfill True
                yfill True

                if persistent.G_I_s_21 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_d_2_card" zoom 0.37
                        action Replay("G_d_2", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.G_O_k_7 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_d_1_card" zoom 0.37
                        action Replay("G_d_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_II_d_3 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_dm_1_card" zoom 0.37
                        action Replay("G_dm_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_III_s_10 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_d_3_card" zoom 0.37
                        action Replay("G_d_3", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch2_enabled == True and persistent.G_IV_o_10 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_d_4_card" zoom 0.37
                        action Replay("G_d_4", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5
    vbox:
        ysize 0.3
        yalign 0.72
        xsize 0.48
        xalign 0.27
        hbox:
            #box_wrap True
            grid 4 1:

                xfill True
                yfill True

                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
    fixed:
        add "gui/title_cards.png" xalign 0.5 ypos 50

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]

screen ali_gallery():

    tag menu
    add "black_bg.jpg"
    fixed:
        vbox:
            ysize 0.58
            yalign 0.51
            xsize 0.2
            xalign 0.91
            hbox:
                grid 1 6:
                    xfill True
                    yfill True


                    button:
                        xalign 0.5
                        yalign 0.5
                        add "lea_gallery"
                        action [Hide("ali_gallery"), ShowMenu("lea_gallery"), SetField(persistent, "CardScreen", 1)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "smm_gallery"
                        action [Hide("ali_gallery"), ShowMenu("smm_gallery"), SetField(persistent, "CardScreen", 2)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "dan_gallery"
                        action [Hide("ali_gallery"), ShowMenu("dan_gallery"), SetField(persistent, "CardScreen", 3)] hovered [Play("sound", "audio/button_hover.wav")]
                    add "gui/mm_ali_hover.jpg" xalign 0.5 yalign 0.5 #hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "mei_gallery"
                        action [Hide("ali_gallery"), ShowMenu("mei_gallery"), SetField(persistent, "CardScreen", 5)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "kat_gallery"
                        action [Hide("ali_gallery"), ShowMenu("kat_gallery"), SetField(persistent, "CardScreen", 6)] hovered [Play("sound", "audio/button_hover.wav")]
    vbox:
        ysize 0.3
        yalign 0.3
        xsize 0.6
        xalign 0.2
        hbox:
            grid 5 1:
                xfill True
                yfill True

                if persistent.patch_enabled == True and persistent.G_II_a_1 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_a_1_card" zoom 0.37
                        action Replay("G_a_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_III_v_1 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_a_2_card" zoom 0.37
                        action Replay("G_a_2", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_III_d_3 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_la_1_card" zoom 0.37
                        action Replay("G_la_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch2_enabled == True and persistent.G_IV_c_11 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_a_3_card" zoom 0.37
                        action Replay("G_a_3", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
    vbox:
        ysize 0.3
        yalign 0.72
        xsize 0.48
        xalign 0.27
        hbox:
            #box_wrap True
            grid 4 1:

                xfill True
                yfill True

                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
    fixed:
        add "gui/title_cards.png" xalign 0.5 ypos 50

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]

screen mei_gallery():

    tag menu
    add "black_bg.jpg"
    fixed:
        vbox:
            ysize 0.58
            yalign 0.51
            xsize 0.2
            xalign 0.91
            hbox:
                grid 1 6:
                    xfill True
                    yfill True

                    button:
                        xalign 0.5
                        yalign 0.5
                        add "lea_gallery"
                        action [Hide("mei_gallery"), ShowMenu("lea_gallery"), SetField(persistent, "CardScreen", 1)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "smm_gallery"
                        action [Hide("mei_gallery"), ShowMenu("smm_gallery"), SetField(persistent, "CardScreen", 2)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "dan_gallery"
                        action [Hide("mei_gallery"), ShowMenu("dan_gallery"), SetField(persistent, "CardScreen", 3)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "ali_gallery"
                        action [Hide("mei_gallery"), ShowMenu("ali_gallery"), SetField(persistent, "CardScreen", 4)] hovered [Play("sound", "audio/button_hover.wav")]
                    add "gui/mm_mei_hover.jpg" xalign 0.5 yalign 0.5 #hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "kat_gallery"
                        action [Hide("mei_gallery"), ShowMenu("kat_gallery"), SetField(persistent, "CardScreen", 6)] hovered [Play("sound", "audio/button_hover.wav")]
    vbox:
        ysize 0.3
        yalign 0.3
        xsize 0.6
        xalign 0.2
        hbox:
            grid 5 1:
                xfill True
                yfill True

                if persistent.G_O_j_2 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_m_1_card" zoom 0.37
                        action Replay("G_m_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.G_I_t_3 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_m_2_card" zoom 0.37
                        action Replay("G_m_2", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_II_d_3 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_dm_1_card" zoom 0.37
                        action Replay("G_dm_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_III_o_30 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_sm_1_card" zoom 0.37
                        action Replay("G_sm_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch2_enabled == True and persistent.G_IV_l_12 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_m_3_card" zoom 0.37
                        action Replay("G_m_3", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5
    vbox:
        ysize 0.3
        yalign 0.72
        xsize 0.48
        xalign 0.27
        hbox:
            #box_wrap True
            grid 4 1:

                xfill True
                yfill True

                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
    fixed:
        add "gui/title_cards.png" xalign 0.5 ypos 50

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]

screen kat_gallery():

    tag menu
    add "black_bg.jpg"
    fixed:
        vbox:
            ysize 0.58
            yalign 0.51
            xsize 0.2
            xalign 0.91
            hbox:
                grid 1 6:
                    xfill True
                    yfill True


                    button:
                        xalign 0.5
                        yalign 0.5
                        add "lea_gallery"
                        action [Hide("kat_gallery"), ShowMenu("lea_gallery"), SetField(persistent, "CardScreen", 1)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "smm_gallery"
                        action [Hide("kat_gallery"), ShowMenu("smm_gallery"), SetField(persistent, "CardScreen", 2)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "dan_gallery"
                        action [Hide("kat_gallery"), ShowMenu("dan_gallery"), SetField(persistent, "CardScreen", 3)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "ali_gallery"
                        action [Hide("kat_gallery"), ShowMenu("ali_gallery"), SetField(persistent, "CardScreen", 4)] hovered [Play("sound", "audio/button_hover.wav")]
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "mei_gallery"
                        action [Hide("kat_gallery"), ShowMenu("mei_gallery"), SetField(persistent, "CardScreen", 5)] hovered [Play("sound", "audio/button_hover.wav")]

                    add "gui/mm_kat_hover.jpg" xalign 0.5 yalign 0.5 #hovered [Play("sound", "audio/button_hover.wav")]
    vbox:
        ysize 0.3
        yalign 0.3
        xsize 0.6
        xalign 0.2
        hbox:
            grid 5 1:
                xfill True
                yfill True

                if persistent.G_O_y_1 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_k_1_card" zoom 0.37
                        action Replay("G_k_1", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch_enabled == True and persistent.G_III_l_2 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_k_2_card" zoom 0.37
                        action Replay("G_k_2", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                if persistent.patch2_enabled == True and persistent.G_A_xld_3 == True:
                    button:
                        xalign 0.5
                        yalign 0.5
                        add "G_k_3_card" zoom 0.37
                        action Replay("G_k_3", locked = False)
                else:
                    add "blank_card" zoom 0.37 xalign 0.5 yalign 0.5

                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
    vbox:
        ysize 0.3
        yalign 0.72
        xsize 0.48
        xalign 0.27
        hbox:
            #box_wrap True
            grid 4 1:

                xfill True
                yfill True

                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5
                add "locked_card" zoom 0.37 xalign 0.5 yalign 0.5

    fixed:
        add "gui/title_cards.png" xalign 0.5 ypos 50

    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("gallery"), ShowMenu("extras")] hovered [Play("sound", "audio/button_hover.wav")]


screen card_button():
    if persistent.G_O_k_7 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (862,191,327,124) action [SetField(persistent, "G_O_k_7", True), Show("collect_card_animation"), SetField(persistent, "animation_G_O_k_7", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_O_y_1 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1093,230,593,394) action [SetField(persistent, "G_O_y_1", True), Show("collect_card_animation"), SetField(persistent, "animation_G_O_y_1", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_O_j_2 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (0,940,271,58) action [SetField(persistent, "G_O_j_2", True), Show("collect_card_animation"), SetField(persistent, "animation_G_O_j_2", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_O_b_1 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1580,975,209,73) action [SetField(persistent, "G_O_b_1", True), Show("collect_card_animation"), SetField(persistent, "animation_G_O_b_1", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_I_t_3 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (0,586,353,358) action [SetField(persistent, "G_I_t_3", True), Show("collect_card_animation"), SetField(persistent, "animation_G_I_t_3", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_I_s_4 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (917,750,165,39) action [SetField(persistent, "G_I_s_4", True), Show("collect_card_animation"), SetField(persistent, "animation_G_I_s_4", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_I_s_21 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (0,555,121,113) action [SetField(persistent, "G_I_s_21", True), Show("collect_card_animation"), SetField(persistent, "animation_G_I_s_21", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_I_b_7 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (310,250,151,117) action [SetField(persistent, "G_I_b_7", True), Show("collect_card_animation"), SetField(persistent, "animation_G_I_b_7", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_A_l_1 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (0,805,69,106) action [SetField(persistent, "G_A_l_1", True), Show("collect_card_animation"), SetField(persistent, "animation_G_A_l_1", True), SetField(persistent, "CardNotifi", True)]

    # Chapter 2

    if persistent.G_II_z_4 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (187,255,806,205) action [SetField(persistent, "G_II_z_4", True), Show("collect_card_animation"), SetField(persistent, "animation_G_II_z_4", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_II_c_2 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (503,921,586,135) action [SetField(persistent, "G_II_c_2", True), Show("collect_card_animation"), SetField(persistent, "animation_G_II_c_2", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_II_a_1 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1056,1002,287,71) action [SetField(persistent, "G_II_a_1", True), Show("collect_card_animation"), SetField(persistent, "animation_G_II_a_1", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_II_d_3 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (216,770,364,213) action [SetField(persistent, "G_II_d_3", True), Show("collect_card_animation"), SetField(persistent, "animation_G_II_d_3", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_II_n_1 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1575,44,310,711) action [SetField(persistent, "G_II_n_1", True), Show("collect_card_animation"), SetField(persistent, "animation_G_II_n_1", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_III_n_4 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (903,532,206,72) action [SetField(persistent, "G_III_n_4", True), Show("collect_card_animation"), SetField(persistent, "animation_G_III_n_4", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_III_l_2 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1045,902,167,175) action [SetField(persistent, "G_III_l_2", True), SetField(persistent, "animation_G_III_l_2", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_III_v_1 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (237,591,198,190) action [SetField(persistent, "G_III_v_1", True), Show("collect_card_animation"), SetField(persistent, "animation_G_III_v_1", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_III_s_10 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (698,1005,96,76) action [SetField(persistent, "G_III_s_10", True), Show("collect_card_animation"), SetField(persistent, "animation_G_III_s_10", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_III_s_42 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1666,394,211,158) action [SetField(persistent, "G_III_s_42", True), Show("collect_card_animation"), SetField(persistent, "animation_G_III_s_42", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_III_d_3 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1150,762,270,87) action [SetField(persistent, "G_III_d_3", True), Show("collect_card_animation"), SetField(persistent, "animation_G_III_d_3", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_III_o_30 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (709,323,111,110) action [SetField(persistent, "G_III_o_30", True), Show("collect_card_animation"), SetField(persistent, "animation_G_III_o_30", True), SetField(persistent, "CardNotifi", True)]

    # Chapter 3

    if persistent.G_IV_l_12 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (468,359,338,134) action [SetField(persistent, "G_IV_l_12", True), Show("collect_card_animation"), SetField(persistent, "animation_G_IV_l_12", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_IV_o_10 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1340,0,300,82) action [SetField(persistent, "G_IV_o_10", True), Show("collect_card_animation"), SetField(persistent, "animation_G_IV_o_10", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_IV_c_11 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (1650,359,273,147) action [SetField(persistent, "G_IV_c_11", True), Show("collect_card_animation"), SetField(persistent, "animation_G_IV_c_11", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_A_xld_3 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (37,700,230,260) action [SetField(persistent, "G_A_xld_3", True), Show("collect_card_animation"), SetField(persistent, "animation_G_A_xld_3", True), SetField(persistent, "CardNotifi", True)]
    if persistent.G_A_xd_4 == False:
        imagemap:
            ground "gui/transparent_background.png" at transparent
            hotspot (109,786,120,170) action [SetField(persistent, "G_A_xd_4", True), Show("collect_card_animation"), SetField(persistent, "animation_G_A_xd_4", True), SetField(persistent, "CardNotifi", True)]






init python:
    config.overlay_screens.append("card_button")

screen collect_card_animation():
    if persistent.animation_G_O_k_7 == True:
        add "G_d_1_animation"
        $ persistent.animation_G_O_k_7 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_O_y_1 == True:
        add "G_k_1_animation"
        $ persistent.animation_G_O_y_1 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_O_j_2 == True:
        add "G_m_1_animation"
        $ persistent.animation_G_O_j_2 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_O_b_1 == True:
        add "G_s_2_animation"
        $ persistent.animation_G_O_b_1 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_I_t_3 == True:
        add "G_m_2_animation"
        $ persistent.animation_G_I_t_3 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_I_s_4 == True:
        add "G_l_1_animation"
        $ persistent.animation_G_I_s_4 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_I_s_21 == True:
        add "G_d_2_animation"
        $ persistent.animation_G_I_s_21 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_I_b_7 == True:
        add "G_ls_1_animation"
        $ persistent.animation_G_I_b_7 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_A_l_1 == True:
        add "G_s_1_animation"
        $ persistent.animation_G_A_l_1 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

#Chapter 2


    if persistent.animation_G_II_z_4 == True:
        add "G_l_3_animation"
        $ persistent.animation_G_II_z_4 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_II_c_2 == True:
        add "G_l_2_animation"
        $ persistent.animation_G_II_c_2 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_II_a_1 == True:
        add "G_a_1_animation"
        $ persistent.animation_G_II_a_1 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_II_d_3 == True:
        add "G_dm_1_animation"
        $ persistent.animation_G_II_d_3 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_II_n_1 == True:
        add "G_s_3_animation"
        $ persistent.animation_G_II_n_1 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_III_n_4 == True:
        add "G_s_4_animation"
        $ persistent.animation_G_III_n_4 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_III_l_2 == True:
    #    add "G_k_2_animation"
        $ persistent.animation_G_III_l_2 = False
    #    timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
    #    timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_III_v_1 == True:
        add "G_a_2_animation"
        $ persistent.animation_G_III_v_1 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_III_s_10 == True:
        add "G_d_3_animation"
        $ persistent.animation_G_III_s_10 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_III_s_42 == True:
        add "G_l_4_animation"
        $ persistent.animation_G_III_s_42 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_III_d_3 == True:
        add "G_la_1_animation"
        $ persistent.animation_G_III_d_3 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_III_o_30 == True:
        add "G_sm_1_animation"
        $ persistent.animation_G_III_o_30 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

# Chapter 3

    if persistent.animation_G_IV_l_12 == True:
        add "G_m_3_animation"
        $ persistent.animation_G_IV_l_12 = False
        timer 0.01 action renpy.music.play("audio/sound/c4/Horror Card Sound.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_IV_o_10 == True:
        add "G_d_4_animation"
        $ persistent.animation_G_IV_o_10 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_IV_c_11 == True:
        add "G_a_3_animation"
        $ persistent.animation_G_IV_c_11 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_A_xld_3 == True:
        add "G_k_3_animation"
        $ persistent.animation_G_A_xld_3 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")

    if persistent.animation_G_A_xd_4 == True:
        add "G_s_5_animation"
        $ persistent.animation_G_A_xd_4 = False
        timer 0.01 action renpy.music.play("audio/sound/Card Collection.mp3","sound")
        timer 12.0 action Hide("collect_card_animation")







#init python:
    #config.overlay_screens.append("collect_card_animation")



## About screen ################################################################
##
## This screen gives credit and copyright information about the game and Ren'Py.
##
## There's nothing special about this screen, and hence it also serves as an
## example of how to make a custom screen.

screen credits():

    tag menu
    text "{color=#7A7054}Special thanks to volf3n" xpos 0.4 ypos 0.4
    imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action Return() hovered [Play("sound", "audio/button_hover.wav")]

screen advertisement():
    tag menu

    add "black_fadein"
    add "ad_backdrop"

    button:
        xalign 0.375
        yalign 0.365
        add "patreon"
        action OpenURL("https://www.patreon.com/dokiden")

    button:
        xalign 0.425
        yalign 0.365
        add "itch"
        action OpenURL("https://dokiden.itch.io/dreamland")

    button:
        xalign 0.475
        yalign 0.365
        add "oppaiman"
        action OpenURL("http://oppai.me/Dreamland__Chapter_2")

    button:
        xalign 0.525
        yalign 0.365
        add "steam"
        action OpenURL("https://store.steampowered.com/app/2176560/Dreamland/")

    button:
        xalign 0.575
        yalign 0.365
        add "discord"
        action OpenURL("https://discord.gg/Q7jG6UuUey")

    button:
        xalign 0.625
        yalign 0.365
        add "twitter"
        action OpenURL("https://twitter.com/DokidenGames")

    add "underline"

    imagebutton auto "gui/mm_leave_%s.png" xalign 0.5 ypos 910 action [Return(), ShowMenu("scenes")] hovered [Play("sound", "audio/button_hover.wav")]

    add "black_fadeout"

screen ending():
    tag menu

    add "black_fadein"
    add "ad_backdrop"

    button:
        xalign 0.375
        yalign 0.365
        add "patreon"
        action OpenURL("https://www.patreon.com/dokiden")

    button:
        xalign 0.425
        yalign 0.365
        add "itch"
        action OpenURL("https://dokiden.itch.io/dreamland")

    button:
        xalign 0.475
        yalign 0.365
        add "oppaiman"
        action OpenURL("http://oppai.me/Dreamland__Chapter_2")

    button:
        xalign 0.525
        yalign 0.365
        add "steam"
        action OpenURL("https://store.steampowered.com/app/2176560/Dreamland/")

    button:
        xalign 0.575
        yalign 0.365
        add "discord"
        action OpenURL("https://discord.gg/Q7jG6UuUey")

    button:
        xalign 0.625
        yalign 0.365
        add "twitter"
        action OpenURL("https://twitter.com/DokidenGames")

    add "underline"

    imagebutton auto "gui/mm_leave_%s.png" xalign 0.5 ypos 910 action [Return(), ShowMenu("scenes")] hovered [Play("sound", "audio/button_hover.wav")]

    add "black_fadeout"

screen about():

    tag menu

    ## This use statement includes the game_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the game_menu
    ## screen.
    use game_menu(_("About"), scroll="viewport"):

        style_prefix "about"

        vbox:

            label "[config.name!t]"
            text _("Version [config.version!t]\n")

            ## gui.about is usually set in options.rpy.
            if gui.about:
                text "[gui.about!t]\n"

            text _("Made with {a=https://www.renpy.org/}Ren'Py{/a} [renpy.version_only].\n\n[renpy.license!t]")


## This is redefined in options.rpy to add text to the about screen.
define gui.about = ""


style about_label is gui_label
style about_label_text is gui_label_text
style about_text is gui_text

style about_label_text:
    size gui.label_text_size


## Load and Save screens #######################################################
##
## These screens are responsible for letting the player save the game and load
## it again. Since they share nearly everything in common, both are implemented
## in terms of a third screen, file_slots.
##
## https://www.renpy.org/doc/html/screen_special.html#save https://
## www.renpy.org/doc/html/screen_special.html#load

screen save():

    tag menu

    use file_slots(_(""))
    fixed:
        add "gui/title_save.png" xalign 0.5 ypos 50

screen load():

    tag menu

    use file_slots(_(""))
    fixed:
        add "gui/title_load.png" xalign 0.5 ypos 50

default persistent.save_naming = True

screen screen_save_name(slot):
    modal True
    zorder 200
    style_prefix "confirm"

    add "gui/overlay/confirm.png"

    frame:
        vbox:
            spacing 25
            xsize 650

            hbox:
                xfill True
                if FileLoadable(slot):
                    label _("Save name ({color=#bb7b8d}overwrite existing save{/color}):") style "confirm_prompt" xalign 0.5
                else:
                    label _("Save name ({color=#7bbb8f}empty slot{/color}):") style "confirm_prompt" xalign 0.5


            input:
                value VariableInputValue('save_name')
                length 30
                xalign 0.5
                exclude "\\[{"

            hbox:
                xfill True
                textbutton _("Save") action FileAction(slot, confirm=False), Hide("screen_save_name") xalign 0.5
                textbutton _("Cancel") action Hide("screen_save_name") xalign 0.5

    ## Right-click and escape answer "no".
    key "game_menu" action Hide("screen_save_name")

    ## Return of Enter answer "yes".
    key "K_RETURN" action FileAction(slot, confirm=False), Hide("screen_save_name")
    key "K_KP_ENTER" action FileAction(slot, confirm=False), Hide("screen_save_name")




screen file_slots(title):

    default page_name_value = FilePageNameInputValue(pattern=_("Page {}"), auto=_("Automatic Saves"), quick=_("Quick Saves"))

    use game_menu(title):

        fixed:


            ## This ensures the input will get the enter event before any of the
            ## buttons do.
            order_reverse True

            ## The page name, which can be edited by clicking on a button.


            ## The grid of file slots.
            grid gui.file_slot_cols gui.file_slot_rows:
                style_prefix "slot"

                xalign 1.22
                yalign 0.4

                spacing gui.slot_spacing

                for i in range(gui.file_slot_cols * gui.file_slot_rows):

                    $ slot = i + 1

                    #button:
                        #action FileAction(slot)

                        #has vbox

                        #add FileScreenshot(slot) xalign 0.5

                        #fixed:

                            #text FileTime(slot, format=_("{#file_time}%A, %B %d %Y, %H:%M"), empty=_("empty slot")):
                                #style "slot_time_text"
                                ##style "page_label_text"
                                #yalign -0.25

                            #text FileSaveName(slot):
                                #style "slot_name_text"


                        #key "save_delete" action FileDelete(slot)

                    button:
                        if renpy.current_screen().screen_name[0] == "load":
                            action FileAction(slot)
                        else:
                            # Highlight if the current save slot is the last save
                            selected (str(persistent._file_page) + "-" + str(slot) == renpy.newest_slot("[0-9]"))
                            if persistent.save_naming:
                                action SetVariable("save_name", FileSaveName(slot)), Show("screen_save_name", slot=slot)
                            else:
                                action SetVariable("save_name", FileSaveName(slot)), FileAction(slot)

                        has vbox

                        add FileScreenshot(slot) xalign 0.5

                        fixed:
                            text FileTime(slot, format=_("{#file_time}%A, %B %d %Y, %H:%M"), empty=_("empty slot")):
                                style "slot_time_text"
                                yalign -0.1

                            text FileSaveName(slot).replace("[","[[").replace("{","{{"):
                                style "slot_name_text"
                                yalign -0.8

                        key "save_delete" action FileDelete(slot)



            ## Buttons to access other pages.
            hbox:
                style_prefix "page"

                xalign 0.175
                yalign 0.08

                spacing gui.page_spacing

                textbutton _("<") action FilePagePrevious()

                if config.has_autosave:
                    textbutton _("{#auto_page}Auto") action FilePage("auto")

                if config.has_quicksave:
                    textbutton _("{#quick_page}Quick") action FilePage("quick")

                ## range(1, 10) gives the numbers from 1 to 9.
                for page in range(1, 10):
                    textbutton "[page]" action FilePage(page)
                textbutton "..." action FilePage(10)

                $ mypage=FileCurrentPage()
                textbutton _(">") action FilePageNext()

                #below is the text for limited page numbers:
                #textbutton _(">") action If (mypage!="9",false=None, true=FilePageNext())



    button:
        #style "page_label"

        key_events True
        xalign 0.5
        yalign 0.205
        action page_name_value.Toggle()

        input:
            style "page_label_text"
            value page_name_value



style page_label is gui_label
style page_label_text is gui_label_text
style page_button is gui_button
style page_button_text is gui_button_text

style slot_button is gui_button
style slot_button_text is gui_button_text
style slot_time_text is slot_button_text
style slot_name_text is slot_button_text

style page_label:
    xpadding 75
    ypadding 5

style page_label_text:
    text_align 0.5
    layout "subtitle"
    hover_color gui.hover_color

style page_button:
    properties gui.button_properties("page_button")

style page_button_text:
    properties gui.button_text_properties("page_button")

style slot_button:
    properties gui.button_properties("slot_button")

style slot_button_text:
    properties gui.button_text_properties("slot_button")




## Preferences screen ##########################################################
##
## The preferences screen allows the player to configure the game to better suit
## themselves.
##
## https://www.renpy.org/doc/html/screen_special.html#preferences

screen preferences():

    tag menu

    use game_menu(_(""), scroll="viewport"):

        vbox:
            ypos 50
            hbox:
                box_wrap True
                xpos 50

                if renpy.variant("pc") or renpy.variant("web"):

                    vbox:
                        style_prefix "radio"
                        label _("Display")
                        textbutton _("Window") action Preference("display", "window")
                        textbutton _("Fullscreen") action Preference("display", "fullscreen")

                vbox:
                    style_prefix "radio"
                    label _("Rollback Side")
                    textbutton _("Disable") action Preference("rollback side", "disable")
                    textbutton _("Left") action Preference("rollback side", "left")
                    textbutton _("Right") action Preference("rollback side", "right")

                vbox:
                    style_prefix "check"
                    label _("Skip")
                    textbutton _("Unseen Text") action Preference("skip", "toggle")
                    textbutton _("After Choices") action Preference("after choices", "toggle")
                    textbutton _("Transitions") action InvertSelected(Preference("transitions", "toggle"))

                ## Additional vboxes of type "radio_pref" or "check_pref" can be
                ## added here, to add additional creator-defined preferences.

            null height (4 * gui.pref_spacing)

            hbox:
                style_prefix "slider"
                box_wrap True
                ypos -5
                vbox:
                    xpos 50

                    label _("Text Speed")

                    bar value Preference("text speed")

                    label _("Auto-Forward Time")

                    bar value Preference("auto-forward time")

                    textbutton _("Controls Menu") action [Hide("preferences"), ShowMenu("help")] xpos -20 ypos 40

                vbox:
                    xpos -95
                    if config.has_music:
                        label _("Music Volume")

                        hbox:
                            bar value Preference("music volume")

                    if config.has_sound:

                        label _("Sound Volume")

                        hbox:
                            bar value Preference("sound volume")

                            if config.sample_sound:
                                textbutton _("Test") action Play("sound", config.sample_sound)


                    if config.has_voice:
                        label _("Voice Volume")

                        hbox:
                            bar value Preference("voice volume")

                            if config.sample_voice:
                                textbutton _("Test") action Play("voice", config.sample_voice)

                    if config.has_music or config.has_sound or config.has_voice:
                        null height gui.pref_spacing

                        textbutton _("Mute All"):
                            action Preference("all mute", "toggle")
                            style "mute_all_button"
    fixed:
        add "gui/title_settings.png" xalign 0.5 ypos 50


style pref_label is gui_label
style pref_label_text is gui_label_text
style pref_vbox is vbox

style radio_label is pref_label
style radio_label_text is pref_label_text
style radio_button is gui_button
style radio_button_text is gui_button_text
style radio_vbox is pref_vbox

style check_label is pref_label
style check_label_text is pref_label_text
style check_button is gui_button
style check_button_text is gui_button_text
style check_vbox is pref_vbox

style slider_label is pref_label
style slider_label_text is pref_label_text
style slider_slider is gui_slider
style slider_button is gui_button
style slider_button_text is gui_button_text
style slider_pref_vbox is pref_vbox

style mute_all_button is check_button
style mute_all_button_text is check_button_text

style pref_label:
    top_margin gui.pref_spacing
    bottom_margin 3

style pref_label_text:
    yalign 1.0

style pref_vbox:
    xsize 338

style radio_vbox:
    spacing gui.pref_button_spacing

style radio_button:
    properties gui.button_properties("radio_button")
    foreground "gui/button/radio_[prefix_]foreground.png"

style radio_button_text:
    properties gui.button_text_properties("radio_button")

style check_vbox:
    spacing gui.pref_button_spacing

style check_button:
    properties gui.button_properties("check_button")
    foreground "gui/button/check_[prefix_]foreground.png"

style check_button_text:
    properties gui.button_text_properties("check_button")

style slider_slider:
    xsize 300#525

style slider_button:
    properties gui.button_properties("slider_button")
    yalign 0.5
    left_margin 15

style slider_button_text:
    properties gui.button_text_properties("slider_button")

style slider_vbox:
    xsize 675


## History screen ##############################################################
##
## This is a screen that displays the dialogue history to the player. While
## there isn't anything special about this screen, it does have to access the
## dialogue history stored in _history_list.
##
## https://www.renpy.org/doc/html/history.html

screen history():

    tag menu

    ## Avoid predicting this screen, as it can be very large.
    predict False

    use game_menu(_("History"), scroll=("vpgrid" if gui.history_height else "viewport"), yinitial=1.0):

        style_prefix "history"

        for h in _history_list:

            window:

                ## This lays things out properly if history_height is None.
                has fixed:
                    yfit True

                if h.who:

                    label h.who:
                        style "history_name"
                        substitute False

                        ## Take the color of the who text from the Character, if
                        ## set.
                        if "color" in h.who_args:
                            text_color h.who_args["color"]

                $ what = renpy.filter_text_tags(h.what, allow=gui.history_allow_tags)
                text what:
                    substitute False

        if not _history_list:
            label _("The dialogue history is empty.")


## This determines what tags are allowed to be displayed on the history screen.

define gui.history_allow_tags = set()


style history_window is empty

style history_name is gui_label
style history_name_text is gui_label_text
style history_text is gui_text

style history_text is gui_text

style history_label is gui_label
style history_label_text is gui_label_text

style history_window:
    xfill True
    ysize gui.history_height

style history_name:
    xpos gui.history_name_xpos
    xanchor gui.history_name_xalign
    ypos gui.history_name_ypos
    xsize gui.history_name_width

style history_name_text:
    min_width gui.history_name_width
    text_align gui.history_name_xalign

style history_text:
    xpos gui.history_text_xpos
    ypos gui.history_text_ypos
    xanchor gui.history_text_xalign
    xsize gui.history_text_width
    min_width gui.history_text_width
    text_align gui.history_text_xalign
    layout ("subtitle" if gui.history_text_xalign else "tex")

style history_label:
    xfill True

style history_label_text:
    xalign 0.5


## Help screen #################################################################
##
## A screen that gives information about key and mouse bindings. It uses other
## screens (keyboard_help, mouse_help, and gamepad_help) to display the actual
## help.

screen help():



    tag menu

    default device = "keyboard"

    use game_menu(_(""), scroll="viewport"):

        style_prefix "help"

        vbox:
            spacing 23
            ypos 50

            hbox:

                textbutton _("Keyboard") action SetScreenVariable("device", "keyboard")
                textbutton _("Mouse") action SetScreenVariable("device", "mouse")

                if GamepadExists():
                    textbutton _("Gamepad") action SetScreenVariable("device", "gamepad")

            if device == "keyboard":
                use keyboard_help
            elif device == "mouse":
                use mouse_help
            elif device == "gamepad":
                use gamepad_help

    fixed:
        add "gui/title_settings.png" xpos 763 ypos 50
        imagebutton auto "gui/mm_return_%s.png" xpos 895 ypos 926 action [Hide("help"), ShowMenu("preferences")] hovered [Play("sound", "audio/button_hover.wav")]

screen keyboard_help():

    vbox:
        hbox:
            label _("Enter")
            text _("Advances dialogue and activates the interface.")

        hbox:
            label _("Space")
            text _("Advances dialogue without selecting choices.")

        hbox:
            label _("Arrow Keys")
            text _("Navigate the interface.")

        hbox:
            label _("Escape")
            text _("Accesses the game menu.")

        hbox:
            label _("Ctrl")
            text _("Skips dialogue while held down.")

        hbox:
            label _("Tab")
            text _("Toggles dialogue skipping.")

        hbox:
            label _("Page Up")
            text _("Rolls back to earlier dialogue.")
        hbox:
            label _("Page Down")
            text _("Rolls forward to later dialogue.")

        hbox:
            label "H"
            text _("Hides the user interface.")

        hbox:
            label "S"
            text _("Takes a screenshot.")

        hbox:
            label "V"
            text _("Toggles assistive {a=https://www.renpy.org/l/voicing}self-voicing{/a}.")


screen mouse_help():

    hbox:
        label _("Left Click")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Middle Click")
        text _("Hides the user interface.")

    hbox:
        label _("Right Click")
        text _("Accesses the game menu.")

    hbox:
        label _("Mouse Wheel Up\nClick Rollback Side")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Mouse Wheel Down")
        text _("Rolls forward to later dialogue.")


screen gamepad_help():

    hbox:
        label _("Right Trigger\nA/Bottom Button")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Left Trigger\nLeft Shoulder")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Right Shoulder")
        text _("Rolls forward to later dialogue.")


    hbox:
        label _("D-Pad, Sticks")
        text _("Navigate the interface.")

    hbox:
        label _("Start, Guide")
        text _("Accesses the game menu.")

    hbox:
        label _("Y/Top Button")
        text _("Hides the user interface.")

    textbutton _("Calibrate") action GamepadCalibrate()

style help_button is gui_button
style help_button_text is gui_button_text
style help_label is gui_label
style help_label_text is gui_label_text
style help_text is gui_text

style help_button:
    properties gui.button_properties("help_button")
    xmargin 12

style help_button_text:
    properties gui.button_text_properties("help_button")

style help_label:
    xsize 375
    right_padding 30

style help_label_text:
    size gui.text_size
    xalign 1.0
    text_align 1.0



################################################################################
## Additional screens
################################################################################


## Confirm screen ##############################################################
##
## The confirm screen is called when Ren'Py wants to ask the player a yes or no
## question.
##
## https://www.renpy.org/doc/html/screen_special.html#confirm

screen confirm(message, yes_action, no_action):

    fixed:
        add "gui/mm_title.png"
    ## Ensure other screens do not get input while this screen is displayed.
    modal True

    zorder 200

    style_prefix "confirm"

    add "gui/overlay/confirm.png"

    frame:

        vbox:
            xalign .5
            yalign .5
            spacing 45

            label _(message):
                style "confirm_prompt"
                xalign 0.5

            hbox:
                xalign 0.5
                spacing 150

                textbutton _("Yes") action yes_action
                textbutton _("No") action no_action

    ## Right-click and escape answer "no".
    key "game_menu" action no_action


style confirm_frame is gui_frame
style confirm_prompt is gui_prompt
style confirm_prompt_text is gui_prompt_text
style confirm_button is gui_medium_button
style confirm_button_text is gui_medium_button_text

style confirm_frame:
    background Frame([ "gui/confirm_frame.png", "gui/frame.png"], gui.confirm_frame_borders, tile=gui.frame_tile)
    padding gui.confirm_frame_borders.padding
    xalign .5
    yalign .5

style confirm_prompt_text:
    text_align 0.5
    layout "subtitle"

style confirm_button:
    properties gui.button_properties("confirm_button")

style confirm_button_text:
    properties gui.button_text_properties("confirm_button")


## Skip indicator screen #######################################################
##
## The skip_indicator screen is displayed to indicate that skipping is in
## progress.
##
## https://www.renpy.org/doc/html/screen_special.html#skip-indicator

screen skip_indicator():

    zorder 100
    style_prefix "skip"

    frame:

        hbox:
            spacing 9

            text _("Skipping")

            text "▸" at delayed_blink(0.0, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.2, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.4, 1.0) style "skip_triangle"


## This transform is used to blink the arrows one after another.
transform delayed_blink(delay, cycle):
    alpha .5

    pause delay

    block:
        linear .2 alpha 1.0
        pause .2
        linear .2 alpha 0.5
        pause (cycle - .4)
        repeat


style skip_frame is empty
style skip_text is gui_text
style skip_triangle is skip_text

style skip_frame:
    ypos gui.skip_ypos
    background Frame("gui/skip.png", gui.skip_frame_borders, tile=gui.frame_tile)
    padding gui.skip_frame_borders.padding

style skip_text:
    size gui.notify_text_size

style skip_triangle:
    ## We have to use a font that has the BLACK RIGHT-POINTING SMALL TRIANGLE
    ## glyph in it.
    font "DejaVuSans.ttf"


## Notify screen ###############################################################
##
## The notify screen is used to show the player a message. (For example, when
## the game is quicksaved or a screenshot has been taken.)
##
## https://www.renpy.org/doc/html/screen_special.html#notify-screen

screen notify(message):

    zorder 100
    style_prefix "notify"

    frame at notify_appear:
        text "[message!tq]"

    timer 3.25 action Hide('notify')


transform notify_appear:
    on show:
        alpha 0
        linear .25 alpha 1.0
    on hide:
        linear .5 alpha 0.0


style notify_frame is empty
style notify_text is gui_text

style notify_frame:
    ypos gui.notify_ypos

    background Frame("gui/notify.png", gui.notify_frame_borders, tile=gui.frame_tile)
    padding gui.notify_frame_borders.padding

style notify_text:
    properties gui.text_properties("notify")


## NVL screen ##################################################################
##
## This screen is used for NVL-mode dialogue and menus.
##
## https://www.renpy.org/doc/html/screen_special.html#nvl


screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            spacing gui.nvl_spacing

        ## Displays dialogue in either a vpgrid or the vbox.
        if gui.nvl_height:

            vpgrid:
                cols 1
                yinitial 1.0

                use nvl_dialogue(dialogue)

        else:

            use nvl_dialogue(dialogue)

        ## Displays the menu, if given. The menu may be displayed incorrectly if
        ## config.narrator_menu is set to True, as it is above.
        for i in items:

            textbutton i.caption:
                action i.action
                style "nvl_button"

    add SideImage() xalign 0.0 yalign 1.0


screen nvl_dialogue(dialogue):

    for d in dialogue:

        window:
            id d.window_id

            fixed:
                yfit gui.nvl_height is None

                if d.who is not None:

                    text d.who:
                        id d.who_id

                text d.what:
                    id d.what_id


## This controls the maximum number of NVL-mode entries that can be displayed at
## once.
define config.nvl_list_length = gui.nvl_list_length

style nvl_window is default
style nvl_entry is default

style nvl_label is say_label
style nvl_dialogue is say_dialogue

style nvl_button is button
style nvl_button_text is button_text

style nvl_window:
    xfill True
    yfill True

    background "gui/nvl.png"
    padding gui.nvl_borders.padding

style nvl_entry:
    xfill True
    ysize gui.nvl_height

style nvl_label:
    xpos gui.nvl_name_xpos
    xanchor gui.nvl_name_xalign
    ypos gui.nvl_name_ypos
    yanchor 0.0
    xsize gui.nvl_name_width
    min_width gui.nvl_name_width
    text_align gui.nvl_name_xalign

style nvl_dialogue:
    xpos gui.nvl_text_xpos
    xanchor gui.nvl_text_xalign
    ypos gui.nvl_text_ypos
    xsize gui.nvl_text_width
    min_width gui.nvl_text_width
    text_align gui.nvl_text_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_thought:
    xpos gui.nvl_thought_xpos
    xanchor gui.nvl_thought_xalign
    ypos gui.nvl_thought_ypos
    xsize gui.nvl_thought_width
    min_width gui.nvl_thought_width
    text_align gui.nvl_thought_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_button:
    properties gui.button_properties("nvl_button")
    xpos gui.nvl_button_xpos
    xanchor gui.nvl_button_xalign

style nvl_button_text:
    properties gui.button_text_properties("nvl_button")



################################################################################
## Mobile Variants
################################################################################

style pref_vbox:
    variant "medium"
    xsize 675

## Since a mouse may not be present, we replace the quick menu with a version
## that uses fewer and bigger buttons that are easier to touch.
screen quick_menu():
    variant "touch"

    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            textbutton _("Back") action Rollback()
            textbutton _("Skip") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Menu") action ShowMenu()


style window:
    variant "small"
    background "gui/phone/textbox.png"

style radio_button:
    variant "small"
    foreground "gui/phone/button/radio_[prefix_]foreground.png"

style check_button:
    variant "small"
    foreground "gui/phone/button/check_[prefix_]foreground.png"

style nvl_window:
    variant "small"
    background "gui/phone/nvl.png"

style main_menu_frame:
    variant "small"
    background "gui/phone/overlay/main_menu.png"

style game_menu_outer_frame:
    variant "small"
    background "gui/phone/overlay/game_menu.png"

style game_menu_navigation_frame:
    variant "small"
    xsize 510

style game_menu_content_frame:
    variant "small"
    top_margin 0

style pref_vbox:
    variant "small"
    xsize 600

style bar:
    variant "small"
    ysize gui.bar_size
    left_bar Frame("gui/phone/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/phone/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    variant "small"
    xsize gui.bar_size
    top_bar Frame("gui/phone/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/phone/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    variant "small"
    ysize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    variant "small"
    xsize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    variant "small"
    ysize gui.slider_size
    base_bar Frame("gui/phone/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/horizontal_[prefix_]thumb.png"

style vslider:
    variant "small"
    xsize gui.slider_size
    base_bar Frame("gui/phone/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/vertical_[prefix_]thumb.png"

style slider_pref_vbox:
    variant "small"
    xsize None

style slider_pref_slider:
    variant "small"
    xsize 900
